@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2006 Steven L. Scott
 
@@ -17,34 +18,33 @@
 */
 #ifndef BOOM_UNIFORM_CORRELATION_MODEL_HPP
 #define BOOM_UNIFORM_CORRELATION_MODEL_HPP
-#include <Models/Policies/NullParamPolicy.hpp>
-#include <Models/Policies/IID_DataPolicy.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
-#include <Models/SpdParams.hpp>
+#include "Models/Policies/IID_DataPolicy.hpp"
+#include "Models/Policies/NullParamPolicy.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
+#include "Models/SpdParams.hpp"
 
-#include <LinAlg/CorrelationMatrix.hpp>
+#include "LinAlg/CorrelationMatrix.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-  class UniformCorrelationModel
-    : public NullParamPolicy,
-      public IID_DataPolicy<SpdParams>,
-      public PriorPolicy,
-      public CorrelationModel
-  {
-  public:
-    UniformCorrelationModel(uint dim);
+  class UniformCorrelationModel : public NullParamPolicy,
+                                  public IID_DataPolicy<SpdParams>,
+                                  public PriorPolicy,
+                                  public CorrelationModel {
+   public:
+    explicit UniformCorrelationModel(uint dim);
     UniformCorrelationModel(const UniformCorrelationModel &);
-    UniformCorrelationModel * clone()const override;
+    UniformCorrelationModel *clone() const override;
 
     void initialize_params();
-    double pdf(Ptr<Data>, bool logscale)const;
-    double logp(const CorrelationMatrix &)const override;
+    double pdf(const Ptr<Data> &dp, bool logscale) const;
+    double logp(const CorrelationMatrix &) const override;
 
-    uint dim()const;
-    CorrelationMatrix sim(RNG &rng = GlobalRng::rng)const;
-  private:
+    uint dim() const;
+    CorrelationMatrix sim(RNG &rng = GlobalRng::rng) const;
+
+   private:
     uint dim_;
   };
-}
-#endif// BOOM_UNIFORM_CORRELATION_MODEL_HPP
+}  // namespace BOOM
+#endif  // BOOM_UNIFORM_CORRELATION_MODEL_HPP
