@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -16,67 +17,67 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/FiniteMixtureModel.hpp>
-#include <cpputil/lse.hpp>
-#include <distributions.hpp>
+#include "Models/FiniteMixtureModel.hpp"
+#include "cpputil/lse.hpp"
+#include "distributions.hpp"
 
 #include <functional>
 #include <stdexcept>
 
-namespace BOOM{
+namespace BOOM {
 
   namespace {
-    typedef FiniteMixtureModel FMM;
+    using FMM = BOOM::FiniteMixtureModel;
   }
 
-  FMM::FiniteMixtureModel(Ptr<MixtureComponent> mcomp, uint S)
-    : MixtureDataPolicy(S),
-      mixing_dist_(new MultinomialModel(S))
-  {
+  FMM::FiniteMixtureModel(const Ptr<MixtureComponent> &mixture_component,
+                          uint S)
+      : MixtureDataPolicy(S), mixing_dist_(new MultinomialModel(S)) {
     mixture_components_.reserve(S);
-    for (uint s=0; s<S; ++s) {
-      Ptr<MixtureComponent> mod = mcomp->clone();
+    for (uint s = 0; s < S; ++s) {
+      Ptr<MixtureComponent> mod = mixture_component->clone();
       mixture_components_.push_back(mod);
     }
     set_observers();
   }
 
-  FMM::FiniteMixtureModel(Ptr<MixtureComponent> mcomp, Ptr<MultinomialModel> pi)
-    : MixtureDataPolicy(pi->dim()),
-      mixing_dist_(pi)
-  {
-    uint S = pi->dim();
-    for (uint s=0; s<S; ++s) {
-      Ptr<MixtureComponent> mp = mcomp->clone();
+  FMM::FiniteMixtureModel(const Ptr<MixtureComponent> &mixture_component,
+                          const Ptr<MultinomialModel> &mixing_weights)
+      : MixtureDataPolicy(mixing_weights->dim()), mixing_dist_(mixing_weights) {
+    uint S = mixing_weights->dim();
+    for (uint s = 0; s < S; ++s) {
+      Ptr<MixtureComponent> mp = mixture_component->clone();
       mixture_components_.push_back(mp);
     }
     set_observers();
   }
 
   FMM::FiniteMixtureModel(const FiniteMixtureModel &rhs)
-    : Model(rhs),
-      LatentVariableModel(rhs),
-      ParamPolicy(rhs),
-      DataPolicy(rhs),
-      mixture_components_(rhs.mixture_components_),
-      mixing_dist_(rhs.mixing_dist_->clone())
-  {
+      : Model(rhs),
+        LatentVariableModel(rhs),
+        ParamPolicy(rhs),
+        DataPolicy(rhs),
+        mixture_components_(rhs.mixture_components_),
+        mixing_dist_(rhs.mixing_dist_->clone()) {
     uint S = number_of_mixture_components();
-    for (uint s =0; s<S; ++s)
+    for (uint s = 0; s < S; ++s) {
       mixture_components_[s] = rhs.mixture_components_[s]->clone();
+    }
     set_observers();
   }
 
-  FMM * FMM::clone() const {return new FMM(*this);}
+  FMM *FMM::clone() const { return new FMM(*this); }
 
   void FMM::clear_component_data() {
     mixing_dist_->clear_data();
     uint S = number_of_mixture_components();
-    for (uint s=0; s<S; ++s) mixture_components_[s]->clear_data();
+    for (uint s = 0; s < S; ++s) {
+      mixture_components_[s]->clear_data();
+    }
   }
 
   void FMM::impute_latent_data(RNG &rng) {
-    const std::vector<Ptr<Data> >  &d(dat());
+    const std::vector<Ptr<Data> > &d(dat());
     std::vector<Ptr<CategoricalData> > hvec(latent_data());
 
     uint n = d.size();
@@ -89,10 +90,10 @@ namespace BOOM{
     const std::vector<Ptr<MixtureComponent> > &mod(mixture_components_);
     Ptr<MultinomialModel> mix(mixing_dist_);
     clear_component_data();
-    for (uint i=0; i<n; ++i) {
-      dPtr dp = d[i];
+    for (uint i = 0; i < n; ++i) {
+      Ptr<Data> dp = d[i];
       Ptr<CategoricalData> cd = hvec[i];
-      if (dp->missing()) {
+      if (dp->missing() != 0u) {
         wsp_ = logpi_;
       } else if (which_mixture_component(i) > 0) {
         int source = which_mixture_component(i);
@@ -104,7 +105,7 @@ namespace BOOM{
         mod[source]->add_data(dp);
         continue;
       } else {
-        for (uint s=0; s<S; ++s) {
+        for (uint s = 0; s < S; ++s) {
           wsp_[s] = logpi_[s] + mod[s]->pdf(dp.get(), true);
         }
       }
@@ -118,21 +119,21 @@ namespace BOOM{
     }
   }
 
-  void FMM::class_membership_probability(Ptr<Data> dp, Vector &ans) const {
+  void FMM::class_membership_probability(const Ptr<Data> &dp,
+                                         Vector &ans) const {
     int S = number_of_mixture_components();
     ans.resize(S);
-    const Vector & log_pi(logpi());
+    const Vector &log_pi(logpi());
     for (int s = 0; s < S; ++s) {
       ans[s] = log_pi[s] + mixture_component(s)->pdf(dp.get(), true);
     }
     ans.normalize_logprob();
   }
 
-  double FMM::last_loglike() const {
-    return last_loglike_;}
+  double FMM::last_loglike() const { return last_loglike_; }
 
   void FMM::set_observers() {
-    mixing_dist_->Pi_prm()->add_observer([this]() {this->observe_pi();});
+    mixing_dist_->Pi_prm()->add_observer([this]() { this->observe_pi(); });
     logpi_current_ = false;
     ParamPolicy::set_models(mixture_components_.begin(),
                             mixture_components_.end());
@@ -146,34 +147,37 @@ namespace BOOM{
     }
   }
 
-  double FMM::pdf(dPtr dp, bool logscale) const {
-    if (!logpi_current_) logpi_ = log(pi());
+  double FMM::pdf(const Ptr<Data> &dp, bool logscale) const {
+    if (!logpi_current_) {
+      logpi_ = log(pi());
+    }
     uint S = number_of_mixture_components();
     wsp_.resize(S);
-    for (uint s=0; s<S; ++s) {
+    for (uint s = 0; s < S; ++s) {
       wsp_[s] = logpi_[s] + mixture_components_[s]->pdf(dp.get(), true);
     }
-    if (logscale) return lse(wsp_);
+    if (logscale) {
+      return lse(wsp_);
+    }
     return sum(exp(wsp_));
   }
 
   uint FMM::number_of_mixture_components() const {
-    return mixture_components_.size();}
-
-  const Vector & FMM::pi() const { return mixing_dist_->pi();}
-  const Vector & FMM::logpi() const {
-    set_logpi();
-    return logpi_;}
-
-  Ptr<MultinomialModel> FMM::mixing_distribution() {
-    return mixing_dist_;
+    return mixture_components_.size();
   }
 
-  const MultinomialModel * FMM::mixing_distribution() const {
+  const Vector &FMM::pi() const { return mixing_dist_->pi(); }
+  const Vector &FMM::logpi() const {
+    set_logpi();
+    return logpi_;
+  }
+
+  Ptr<MultinomialModel> FMM::mixing_distribution() { return mixing_dist_; }
+
+  const MultinomialModel *FMM::mixing_distribution() const {
     return mixing_dist_.get();
   }
 
-
   Ptr<MixtureComponent> FMM::mixture_component(int s) {
     return mixture_components_[s];
   }
@@ -182,7 +186,7 @@ namespace BOOM{
     return mixture_components_[s].get();
   }
 
-  const Matrix & FMM::class_membership_probability() const {
+  const Matrix &FMM::class_membership_probability() const {
     return class_membership_probabilities_;
   }
 
@@ -190,45 +194,45 @@ namespace BOOM{
     std::vector<Ptr<CategoricalData> > hvec(latent_data());
     int n = hvec.size();
     Vector ans(n);
-    for (int i = 0; i < n; ++i) ans[i] = hvec[i]->value();
+    for (int i = 0; i < n; ++i) {
+      ans[i] = hvec[i]->value();
+    }
     return ans;
   }
 
   std::vector<Ptr<MixtureComponent> > FMM::models() {
-    return mixture_components_;}
+    return mixture_components_;
+  }
   const std::vector<Ptr<MixtureComponent> > FMM::models() const {
-    return mixture_components_;}
+    return mixture_components_;
+  }
 
   void FMM::observe_pi() const { logpi_current_ = false; }
 
   //======================================================================
 
   EmFiniteMixtureModel::EmFiniteMixtureModel(
-      Ptr<EmMixtureComponent> prototype_mixture_component,
+      const Ptr<EmMixtureComponent> &prototype_mixture_component,
       uint state_space_size)
-    : FiniteMixtureModel(prototype_mixture_component, state_space_size)
-  {
+      : FiniteMixtureModel(prototype_mixture_component, state_space_size) {
     populate_em_mixture_components();
   }
 
   EmFiniteMixtureModel::EmFiniteMixtureModel(
-      Ptr<EmMixtureComponent> prototype_mixture_component,
-      Ptr<MultinomialModel> mixing_distribution)
-      : FiniteMixtureModel(prototype_mixture_component,
-                           mixing_distribution)
-  {
+      const Ptr<EmMixtureComponent> &prototype_mixture_component,
+      const Ptr<MultinomialModel> &mixing_distribution)
+      : FiniteMixtureModel(prototype_mixture_component, mixing_distribution) {
     populate_em_mixture_components();
   }
 
-  EmFiniteMixtureModel::EmFiniteMixtureModel(
-      const EmFiniteMixtureModel &rhs)
-      : FiniteMixtureModel(rhs)
-  {
+  EmFiniteMixtureModel::EmFiniteMixtureModel(const EmFiniteMixtureModel &rhs)
+      : FiniteMixtureModel(rhs) {
     populate_em_mixture_components();
   }
 
-  EmFiniteMixtureModel * EmFiniteMixtureModel::clone() const {
-    return new EmFiniteMixtureModel(*this);}
+  EmFiniteMixtureModel *EmFiniteMixtureModel::clone() const {
+    return new EmFiniteMixtureModel(*this);
+  }
 
   void EmFiniteMixtureModel::populate_em_mixture_components() {
     for (int s = 0; s < mixing_distribution()->dim(); ++s) {
@@ -238,7 +242,7 @@ namespace BOOM{
   }
 
   double EmFiniteMixtureModel::loglike() const {
-    const std::vector<Ptr<Data> >  &d(dat());
+    const std::vector<Ptr<Data> > &d(dat());
     uint n = d.size();
     uint S = number_of_mixture_components();
 
@@ -246,8 +250,8 @@ namespace BOOM{
     Vector wsp(S);
     double ans = 0;
 
-    for (uint i=0; i<n; ++i) {
-      for (uint s=0; s<S; ++s) {
+    for (uint i = 0; i < n; ++i) {
+      for (uint s = 0; s < S; ++s) {
         wsp[s] = log_pi[s] + mixture_component(s)->pdf(d[i].get(), true);
       }
       ans += lse(wsp);
@@ -258,7 +262,7 @@ namespace BOOM{
   void EmFiniteMixtureModel::mle() {
     double eps = 1e-5;
     double old_loglike = EStep();
-    double crit = 1+eps;
+    double crit = 1 + eps;
     while (crit > eps) {
       MStep(false);
       double loglike = EStep();
@@ -289,28 +293,30 @@ namespace BOOM{
         em_mixture_components_[s]->add_mixture_data(
             data[i], wsp[s] / normalizing_constant);
       }
-      mixing_distribution()->suf()->add_mixture_data(
-          wsp / normalizing_constant);
+      mixing_distribution()->suf()->add_mixture_data(wsp /
+                                                     normalizing_constant);
     }
     return ans;
   }
 
   void EmFiniteMixtureModel::MStep(bool posterior_mode) {
     for (int s = 0; s < number_of_mixture_components(); ++s) {
-      if (posterior_mode) em_mixture_component(s)->find_posterior_mode();
-      else em_mixture_component(s)->mle();
+      if (posterior_mode) {
+        em_mixture_component(s)->find_posterior_mode();
+      } else {
+        em_mixture_component(s)->mle();
+      }
     }
     mixing_distribution()->mle();
   }
 
-  Ptr<EmMixtureComponent>
-  EmFiniteMixtureModel::em_mixture_component(int s) {
+  Ptr<EmMixtureComponent> EmFiniteMixtureModel::em_mixture_component(int s) {
     return em_mixture_components_[s];
   }
 
-  const EmMixtureComponent *
-  EmFiniteMixtureModel::em_mixture_component(int s) const {
+  const EmMixtureComponent *EmFiniteMixtureModel::em_mixture_component(
+      int s) const {
     return em_mixture_components_[s].get();
   }
 
-}
+}  // namespace BOOM
