@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2014 Steven L. Scott
 
@@ -16,28 +17,24 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/Glm/PosteriorSamplers/PoissonRegressionAuxMixSampler.hpp>
-#include <Models/Glm/PosteriorSamplers/poisson_mixture_approximation_table.hpp>
-#include <distributions.hpp>
+#include "Models/Glm/PosteriorSamplers/PoissonRegressionAuxMixSampler.hpp"
+#include "Models/Glm/PosteriorSamplers/poisson_mixture_approximation_table.hpp"
+#include "distributions.hpp"
 
 namespace BOOM {
 
   namespace {
     typedef PoissonRegressionAuxMixSampler PRAMS;
     typedef LatentDataSampler<PoissonRegressionDataImputer> Parent;
-  }
+  }  // namespace
 
   PoissonRegressionDataImputer::PoissonRegressionDataImputer(
-      WeightedRegSuf &global_suf,
-      std::mutex &global_suf_mutex,
-      const GlmCoefs *coefficients,
-      RNG *rng,
-      RNG &seeding_rng)
+      WeightedRegSuf &global_suf, std::mutex &global_suf_mutex,
+      const GlmCoefs *coefficients, RNG *rng, RNG &seeding_rng)
       : SufstatImputeWorker<PoissonRegressionData, WeightedRegSuf>(
             global_suf, global_suf_mutex, rng, seeding_rng),
         coefficients_(coefficients),
-        imputer_(new PoissonDataImputer)
-  {}
+        imputer_(new PoissonDataImputer) {}
 
   // The latent variable scheme imagines the event times of y[i]
   // events from a Poisson process that occur in the interval [0, 1].
@@ -59,8 +56,7 @@ namespace BOOM {
   // exponential, and conditionally truncated exponential with support
   // above 1 - tau[i].
   void PoissonRegressionDataImputer::impute_latent_data_point(
-      const PoissonRegressionData &dp,
-      WeightedRegSuf *complete_data_suf,
+      const PoissonRegressionData &dp, WeightedRegSuf *complete_data_suf,
       RNG &rng) {
     const Vector &x(dp.x());
     double eta = coefficients_->predict(x);
@@ -72,45 +68,35 @@ namespace BOOM {
     double neglog_final_interarrival_time;
     double external_mu;
     double external_weight;
-    imputer_->impute(rng,
-                     y,
-                     exposure,
-                     eta,
-                     &internal_neglog_final_event_time,
-                     &internal_mu,
-                     &internal_weight,
-                     &neglog_final_interarrival_time,
-                     &external_mu,
+    imputer_->impute(rng, y, exposure, eta, &internal_neglog_final_event_time,
+                     &internal_mu, &internal_weight,
+                     &neglog_final_interarrival_time, &external_mu,
                      &external_weight);
     if (y > 0) {
       complete_data_suf->add_data(
           x, internal_neglog_final_event_time - internal_mu, internal_weight);
     }
-    complete_data_suf->add_data(
-        x, neglog_final_interarrival_time - external_mu, external_weight);
+    complete_data_suf->add_data(x, neglog_final_interarrival_time - external_mu,
+                                external_weight);
   }
 
   //======================================================================
 
-  PRAMS::PoissonRegressionAuxMixSampler(
-      PoissonRegressionModel *model,
-      Ptr<MvnBase> prior,
-      int number_of_imputation_workers,
-      RNG &seeding_rng)
+  PRAMS::PoissonRegressionAuxMixSampler(PoissonRegressionModel *model,
+                                        const Ptr<MvnBase> &prior,
+                                        int number_of_imputation_workers,
+                                        RNG &seeding_rng)
       : PosteriorSampler(seeding_rng),
         model_(model),
         prior_(prior),
         complete_data_suf_(model_->xdim()),
-        first_pass_through_data_(true)
-  {
+        first_pass_through_data_(true) {
     set_number_of_workers(number_of_imputation_workers);
   }
 
-  double PRAMS::logpri()const{
-    return prior_->logp(model_->Beta());
-  }
+  double PRAMS::logpri() const { return prior_->logp(model_->Beta()); }
 
-  void PRAMS::draw(){
+  void PRAMS::draw() {
     impute_latent_data();
     draw_beta_given_complete_data();
   }
@@ -125,24 +111,20 @@ namespace BOOM {
     }
   }
 
-  void PRAMS::draw_beta_given_complete_data(){
+  void PRAMS::draw_beta_given_complete_data() {
     SpdMatrix ivar = prior_->siginv() + complete_data_suf_.xtx();
     Vector ivar_mu = prior_->siginv() * prior_->mu() + complete_data_suf_.xty();
     Vector beta = rmvn_suf_mt(rng(), ivar, ivar_mu);
     model_->set_Beta(beta);
   }
 
-  const WeightedRegSuf & PRAMS::complete_data_sufficient_statistics() const {
+  const WeightedRegSuf &PRAMS::complete_data_sufficient_statistics() const {
     return complete_data_suf_;
   }
 
   Ptr<PoissonRegressionDataImputer> PRAMS::create_worker(std::mutex &m) {
     return new PoissonRegressionDataImputer(
-        complete_data_suf_,
-        m,
-        model_->coef_prm().get(),
-        nullptr,
-        rng());
+        complete_data_suf_, m, model_->coef_prm().get(), nullptr, rng());
   }
 
   void PRAMS::set_number_of_workers(int n) {
@@ -153,22 +135,17 @@ namespace BOOM {
     Parent::set_number_of_workers(n);
   }
 
-  void PRAMS::clear_latent_data() {
-    complete_data_suf_.clear();
-  }
+  void PRAMS::clear_latent_data() { complete_data_suf_.clear(); }
 
   void PRAMS::clear_complete_data_sufficient_statistics() {
     complete_data_suf_.clear();
   }
 
   void PRAMS::update_complete_data_sufficient_statistics(
-      double precision_weighted_sum,
-      double total_precision,
+      double precision_weighted_sum, double total_precision,
       const Vector &predictors) {
     complete_data_suf_.add_data(
-        predictors,
-        precision_weighted_sum / total_precision,
-        total_precision);
+        predictors, precision_weighted_sum / total_precision, total_precision);
   }
 
   void PRAMS::assign_data_to_workers() {
