@@ -79,9 +79,9 @@ namespace BOOM {
     if (quick_and_dirty) {
       ans.reflect();
     } else {
-      ans = .5 * (ans + ans.t());
+      ans = .5 * (ans + ans.transpose());
     }
-    return ans;
+    return std::move(ans);
   }
 
   double NumericalDerivatives::homogeneous_scalar_second_derivative(
